@@ -66,7 +66,7 @@ function [warped, valid] = imremap(im, XI, YI, interp = "bilinear", extrapval =
     error("imremap: XI and YI must be matrices of the same size");
   endif
   
-  if (!any(strcmpi(interp, {"nearest", "linear", "bilinear", "cubic", "bicubic"})))
+  if (!any(strcmpi(interp, {"nearest", "linear", "bilinear", "cubic", "bicubic", "spline"})))
     error("imremap: unsupported interpolation method");
   endif
   if (any(strcmpi(interp, {"bilinear", "bicubic"})))
@@ -100,11 +100,11 @@ function [warped, valid] = imremap(im, XI, YI, interp = "bilinear", extrapval =
 endfunction
 
 function [warped, valid] = grayinterp(im, XI, YI, interp, extrapval)
-  if (strcmp(interp, "cubic"))
-    warped = graybicubic(double(im), XI, YI, NA);
-  else
+  %if (strcmp(interp, "cubic"))
+  %  warped = graybicubic(double(im), XI, YI, NA);
+  %else
     warped = interp2(double(im), XI, YI, interp, NA);
-  endif
+  %endif
   valid = !isna(warped);
   warped(!valid) = extrapval;
 endfunction
